@@ -26,14 +26,11 @@ import argparse
 import contextlib
 import errno
 import os
-import re
 import socket
 import sys
-import urllib
 import urlparse
 import xmlrpclib
 
-import simplejson
 
 from lava_tool.authtoken import AuthenticatingServerProxy, KeyringAuthBackend
 from lava.tool.command import Command, CommandGroup
@@ -554,7 +551,7 @@ class deserialize(XMLRPCCommand):
                             help="SHA1 of the bundle to deserialize")
 
     def invoke_remote(self):
-        response = self.server.deserialize(self.args.SHA1)
+        self.server.deserialize(self.args.SHA1)
         print "Bundle {sha1} deserialized".format(
             sha1=self.args.SHA1)
 
@@ -907,15 +904,3 @@ class query_data_view(XMLRPCCommand):
             for row in response["rows"]]
         # Print the data
         renderer.render(data_for_renderer)
-
-
-class version(Command):
-
-    """
-    Show dashboard client version
-    """
-
-    def invoke(self):
-        from lava_tool import version
-        print "Dashboard client version: {version}".format(
-            version=version())
